[PATCH 4/10] support W3400N

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



This patch adds support for Asus W3400N.

Signed-off-by: Karol Kozimor <sziwan@xxxxxxxxxxx>

--- a/drivers/acpi/asus_acpi.c	2006-01-18 17:32:25.000000000 +0100
+++ b/drivers/acpi/asus_acpi.c	2006-01-18 17:36:00.000000000 +0100
@@ -130,7 +130,7 @@ struct asus_hotk {
 		L8L,		//L8400L
 		M1A,		//M1300A
 		M2E,		//M2400E, L4400L
-		M6N,		//M6800N
+		M6N,		//M6800N, W3400N
 		M6R,		//M6700R, A3000G
 		P30,		//Samsung P30
 		S1x,		//S1300A, but also L1400B and M2400A (L84F)
@@ -1090,7 +1090,8 @@ static int __init asus_hotk_get_info(voi
 		hotk->model = L8L;
 	else if (strncmp(model->string.pointer, "L4R", 3) == 0)
 		hotk->model = L4R;
-	else if (strncmp(model->string.pointer, "M6N", 3) == 0)
+	else if (strncmp(model->string.pointer, "M6N", 3) == 0 ||
+		 strncmp(model->string.pointer, "W3N", 3) == 0)
 		hotk->model = M6N;
 	else if (strncmp(model->string.pointer, "M6R", 3) == 0 ||
 		 strncmp(model->string.pointer, "A3G", 3) == 0)
@@ -1143,9 +1144,10 @@ static int __init asus_hotk_get_info(voi
 		hotk->methods->lcd_status = "\\BLFG";
 	/* A3G is like M6R */
 	else if (strncmp(model->string.pointer, "S5N", 3) == 0 ||
-		 strncmp(model->string.pointer, "M5N", 3) == 0)
+		 strncmp(model->string.pointer, "M5N", 3) == 0 ||
+		 strncmp(model->string.pointer, "W3N", 3) == 0)
 		hotk->methods->mt_mled = NULL;
 	/* S5N and M5N have no MLED */
 	else if (strncmp(model->string.pointer, "M2N", 3) == 0)
 		hotk->methods->mt_wled = "WLED";
 	/* M2N has a usable WLED */
-
@@ -1143,9 +1144,10 @@ static int __init asus_hotk_get_info(voi
 		hotk->methods->mt_mled = NULL;
-	/* S5N and M5N have no MLED */
+	/* S5N, M5N and W3N have no MLED */
 	else if (strncmp(model->string.pointer, "M2N", 3) == 0)
 		hotk->methods->mt_wled = "WLED";
To unsubscribe from this list: send the line "unsubscribe linux-acpi" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html

[Index of Archives]     [Linux IBM ACPI]     [Linux Power Management]     [Linux Kernel]     [Linux Laptop]     [Kernel Newbies]     [Share Photos]     [Security]     [Netfilter]     [Bugtraq]     [Yosemite News]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Samba]     [Video 4 Linux]     [Device Mapper]     [Linux Resources]

  Powered by Linux